* Cartel Stability in Experimental Auctions
* Jeroen Hinloopen, Sander Onderstal, and Leonard Treuren
* April 2020


* Load data
*******************************************************************************


clear
cd "C:\Users\leona\Desktop\Research\Project 2 Collusion and the Choice of Auction\New Data and Stata" 
dir
use RawDataFull.dta


* Preparation
*******************************************************************************


	*label variables
	label variable treatment "1:FPR; 2:ENR; 3:FPF; 4:ENF"
	label variable round "round"
	label variable number "subject id"
	label variable group "cartel"
	label variable matchinggroup "rematching group"
	label variable value "subject valuation"
	label variable desigwin "designated winner id"
	label variable bid "bid"											// not participating is coded as bid=-1
	label variable winner "1:subject wins auction"
	label variable payment "payment"
	
	*round selection
	*drop if round<6
	*drop if round>35

	bysort round: gen nround = _n == 1
	replace nround = sum(nround)
	replace nround = nround[_N] 
	label variable nround "rounds in treatment"
	
	*generate dummies for the designated winner, defectors, and unstable cartels
	gen deswin = 0
	replace deswin = 1 if desigwin==number
	label variable deswin "1: subject is designated winner"
	gen defect = 0 																
	replace defect = 1 if bid>=0 & deswin==0
	label variable defect "1:subject defects"
	bysort group round: egen unstable = total(defect)
	replace unstable = 1 if unstable>0
	label variable unstable "1:cartel unstable"

	*generate variables relating to values
	bysort group round: egen firstval = max(value)
	label variable firstval "highest value in cartel"
	bysort group round: egen secondval = median(value)
	label variable secondval "median value in cartel"
	bysort group round: egen thirdval = min(value)
	label variable thirdval "lowest value in cartel"
	bysort group round: egen avgval = mean(value)
	label variable avgval "average value in cartel"
	bysort group round: egen sdval = sd(value)
	label variable sdval "sd of values in cartel"
	gen varval = sdval^2
	label variable varval "variance of values in cartel"
	bysort group round: egen maxvaldefect = max(value) if deswin!=1 & defect==1
	label variable maxvaldefect "highest value of defecting subjects"
	gen dummysecondval = 0
	replace dummysecondval = 1 if secondval==value&deswin==0			// deswin==0 ensures that designated winner is not included in defection statistics when max(value)=median(value) in a cartel
	label variable dummysecondval "1:subject has median value in cartel"
	gen dummythirdval = 0
	replace dummythirdval = 1 if thirdval==value&secondval!=value		// secondval!=value ensures that both defectors are registered as second value when median(value)=min(value) in a cartel
	label variable dummythirdval "1:subject has lowest value in cartel"
	bysort matchinggroup unstable: egen avgfirstvalstab = mean(firstval)		// average over all groups and rounds
	label variable avgfirstvalstab "average first values, by (matchinggroup)x(cartel stability)"
	bysort matchinggroup unstable: egen avgsecondvalstab = mean(secondval)		// average over all groups and rounds
	label variable avgsecondvalstab "average second values, by (matchinggroup)x(cartel stability)"
	bysort matchinggroup unstable: egen avgthirdvalstab = mean(thirdval)		// average over all groups and rounds
	label variable avgthirdvalstab "average third values, by (matchinggroup)x(cartel stability)"
	bysort matchinggroup unstable: egen avgvalstab = mean(value)		// average over all groups and rounds
	label variable avgvalstab "average values, by (matchinggroup)x(cartel stability)"
	bysort matchinggroup unstable: egen sdvalstab = mean(sdval)			// average of the (group)x(round) standard deviations
	label variable sdvalstab "average sd values, by (matchinggroup)x(cartel stability)"
	bysort matchinggroup unstable: egen varvalstab = mean(varval)			// average of the (group)x(round) variances
	label variable varvalstab "average variance values, by (matchinggroup)x(cartel stability)"
	gen firstdiff = firstval-secondval 									
	label variable firstdiff "difference between highest and median value in cartel"
	gen seconddiff = secondval-thirdval									
	label variable seconddiff "difference between median and lowest value in cartel"
	bysort matchinggroup unstable: egen firstvalstab = mean(firstval)	// average of the (group)x(round) highest values
	label variable firstvalstab "average highest value in cartel, by (matchinggroup)x(cartel stability)"
	bysort matchinggroup unstable: egen secondvalstab = mean(secondval)	// average of the (group)x(round) median values
	label variable secondvalstab "average median value in cartel, by (matchinggroup)x(cartel stability)"
	gen firstdiffstab = firstvalstab-secondvalstab
	label variable firstdiffstab "average difference between the highest and median value in cartel, by (matchinggroup)x(cartel stability)"
	gen maxminusmin = firstval-thirdval
	label variable maxminusmin "difference between highest and median value in cartel"
	gen valwinner = value if winner==1
	label variable valwinner "value of the winner"
	gen winminusmin = valwinner-thirdval
	label variable winminusmin "difference between winner's value and lowest value in cartel"
	gen ones = 1
	label variable ones "ones"

	*generate variables related to bids
	bysort group round: egen winbid = max(bid)
	gen bidfrac = bid/secondval
	label variable bidfrac "bid as fraction median value in cartel"
	bysort matchinggroup: egen avgrev = mean(bidfrac) if winner!=0		// works for EN due to clock implementation (strictly speaking we don't see the bid, just the payment)
	label variable avgrev "average winning bid, by matchinggroup"
	bysort matchinggroup: egen avgrevsd = sd(bidfrac) if winner!=0
	label variable avgrevsd "sd of winning bids, by matchinggroup"
	gen avgrevvar = avgrevsd^2 
	label variable avgrevvar "variance of winning bids, by matchinggroup"
	bysort matchinggroup unstable: egen avgrevun = mean(bidfrac) if winner!=0
	label variable avgrevun "average winning bid, by (matchinggroup)x(cartel stability)"
	bysort matchinggroup: egen avgbiddefector = mean(bidfrac) if defect==1
	label variable avgbiddefector "average bid of defectors, by matchinggroup"
	bysort matchinggroup: egen avgbiddeswin = mean(bidfrac) if deswin==1
	label variable avgbiddeswin "average bid of designated winners, by matchinggroup"
	bysort matchinggroup: egen avgbiddeslosewin = mean(bidfrac) if deswin==0 & winner==1
	label variable avgbiddeslosewin "average bid of defectors that win, by matchinggroup"
	bysort treatment: egen countbidabove = count(firstval) if bid>value
	label variable countbidabove "count of bids above value by treatment"
	bysort treatment: egen countbidabovedesloselose = count(firstval) if bid>value & winner==0 & deswin==0
	label variable countbidabovedesloselose "count of bids above value by defectors that lose, by treatment"
	bysort group round: egen maxbiddefect = max(bidfrac) if defect==1
	replace maxbiddefect = . if bidfrac!=maxbiddefect
	label variable maxbiddefect "highest bid by defector in cartel"
	gen dummyhighdefect = 0
	replace dummyhighdefect = 1 if maxbiddefect!=.
	label variable dummyhighdefect "subject is defector with highest bid"
	
	*generate variables relating to rounds
	gen dum5 = 0
	replace dum5 = 1 if round<6
	label variable dum5 "1:round<6"
	gen dum35 = 0
	replace dum35 = 1 if round>35
	label variable dum35 "1:round>35"

	*generate variables cartel stability
	bysort matchinggroup: egen df = total(defect)
	gen defectgroup = 0
	replace defectgroup = df/(nround*6) if treatment<3				// in each matchinggroup, 6 subjects can defect each round
	replace defectgroup = df/(nround*2) if treatment>2				// in each matchinggroup, 2 subjects can defect each round
	label variable defectgroup "defections as fraction of all designated losers"
	bysort treatment matchinggroup: egen us = total(unstable)
	gen unstablegroup = 0
	replace unstablegroup = us/(nround*9) if treatment<3			
	replace unstablegroup = us/(nround*3) if treatment>2	
	label variable unstablegroup "unstable cartels as fraction of all cartels"
	drop df us
	bysort matchinggroup: egen defectsecondval = mean(defect) if dummysecondval==1
	label variable defectsecondval "defection as fraction of potential defection for the median value, by matchinggroup"
	bysort matchinggroup: egen defectthirdval = mean(defect) if dummythirdval==1
	label variable defectthirdval "defection as fraction of potential defection for the lowest value, by matchinggroup"
		
	*generate variables related to efficiency
	bysort matchinggroup: egen countdeswinwins = total(deswin) if winner==1
	label variable countdeswinwins "count cartels where designated winner won"
	gen probdeswinwins = 0
	replace probdeswinwins = countdeswinwins/(nround*3)	if treatment<3	// rounds with 3 designated winners in each matchinggroup
	replace probdeswinwins = countdeswinwins/(nround)	if treatment>2	// rounds with 1 designated winner in each mathinggroup
	label variable probdeswinwins "deswin's wins as fraction of total cartels'"
	bysort matchinggroup: egen efficiency = mean(winminusmin/maxminusmin)
	label variable efficiency "1 is most efficient, 0 least efficient"
	bysort round treatment: egen countdeswinwinsround = total(deswin) if winner==1
	gen probdeswinwinsround = 0
	replace probdeswinwinsround = countdeswinwinsround/(3*8) if treatment<3
	replace probdeswinwinsround = countdeswinwinsround/9 if treatment>2
	label variable probdeswinwinsround "deswin's wins as a fraction of cartels each round"
				
	*generate tags for ranksums
	sort treatment matchinggroup
	egen tag = tag(matchinggroup)
	label variable tag "tag matchinggroup"
	egen tagstab = tag(matchinggroup unstable)
	label variable tagstab "tag (matchinggroup)x(unstable)"
	egen tagwinner = tag(matchinggroup) if winner==1
	label variable tagwinner "tag matchinggroup if winner==1"
	egen tagwinnerstab = tag(treatment matchinggroup unstable) if winner==1
	label variable tagwinnerstab "tag (matchinggroup)x(unstable) if winner==1"
	egen tagwinnerstable = tag(treatment matchinggroup) if winner==1 & unstable==0
	label variable tagwinnerstable "tag matchinggroup if winner==1 and unstable==0"
	egen tagwinnerunstable = tag(treatment matchinggroup) if winner==1 & unstable==1
	label variable tagwinnerunstable "tag matchinggroup if winner==1 and unstable==1"
	egen tagcrossfp = tag(matchinggroup) if winner==1 & unstable==0 & (treatment==1|treatment==3)
	label variable tagcrossfp "tag FP matchinggroup if winner==1 and unstable==0"
	egen tagcrossen = tag(matchinggroup) if winner==1 & unstable==1 & (treatment==2|treatment==4)
	label variable tagcrossen "tag EN matchinggroup if winner==1 and unstable==1"
	gen tagcross = 0
	replace tagcross = tagcrossfp if (treatment==1|treatment==3)
	replace tagcross = tagcrossen if (treatment==2|treatment==4)
	label variable tagcross "tag matchinggroup for cross comparison"
	egen tagdefector = tag(matchinggroup) if defect==1
	label variable tagdefector "tag matchinggroup if defect==1"
	egen tagdeswin = tag(matchinggroup) if deswin==1
	label variable tagdeswin "tag matchinggroup if deswin==1"
	egen tagdeslosewins = tag(matchinggroup) if deswin==0 & winner==1
	label variable tagdeslosewins "tag matchinggroup if deswin==0 and winner==1"
	
* Revision

	*Scatter value-bid vs. round for EN deswin exiting below value
	preserve 
	keep if treatment==2&deswin==1&winner==0&bid<value	//in round 22, group 34, no one submitted a bid, that is not counted
	gen diff = value-bid
	label variable diff "value minus bid"
	graph twoway scatter diff round
	restore
	
	*Deslose's winning bid in EN if deswin exited below value
	*sort treatment round group
	*egen cartel = group(treatment round group)
	*glevelsof cartel if treatment==2&deswin==1&winner==0&bid<value, local(strangesecond)
	*gen winnersurplus=.
	*foreach i of local strangesecond{
	*	replace winnersurplus = value-bid if winner==1&cartel==`i'
	*}
	

	

	
* Section 4: Study 1
*******************************************************************************
	
	
*4.1 cartel stability

	
	*paragraph 1 & table 1
	save temp, replace
		keep if tag==1 & treatment<3
		ranksum(defectgroup), by(treatment)
		ranksum(unstablegroup), by(treatment)
		sum defectgroup unstablegroup if treatment==1
		sum defectgroup unstablegroup if treatment==2
	use temp, clear
	
	*paragraph 2 & table 2
	save temp, replace
		keep if tagstab==1 & treatment==1
		keep avgvalstab matchinggroup unstable
		sum avgvalstab if unstable==0
		sum avgvalstab if unstable==1
		reshape wide avgvalstab, i(matchinggroup) j(unstable)
		signrank avgvalstab0=avgvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==1
		keep sdvalstab matchinggroup unstable
		sum sdvalstab if unstable==0
		sum sdvalstab if unstable==1
		reshape wide sdvalstab, i(matchinggroup) j(unstable)
		signrank sdvalstab0=sdvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==1
		keep firstdiffstab matchinggroup unstable
		sum firstdiffstab if unstable==0
		sum firstdiffstab if unstable==1
		reshape wide firstdiffstab, i(matchinggroup) j(unstable)
		signrank firstdiffstab0=firstdiffstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==2
		keep avgvalstab matchinggroup unstable
		sum avgvalstab if unstable==0
		sum avgvalstab if unstable==1
		reshape wide avgvalstab, i(matchinggroup) j(unstable)
		signrank avgvalstab0=avgvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==2
		keep sdvalstab matchinggroup unstable
		sum sdvalstab if unstable==0
		sum sdvalstab if unstable==1
		reshape wide sdvalstab, i(matchinggroup) j(unstable)
		signrank sdvalstab0=sdvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==2
		keep firstdiffstab matchinggroup unstable
		sum firstdiffstab if unstable==0
		sum firstdiffstab if unstable==1
		reshape wide firstdiffstab, i(matchinggroup) j(unstable)
		signrank firstdiffstab0=firstdiffstab1
	use temp, clear	
	save temp, replace
		keep if treatment==1 & deswin==0
		egen countdefectors = total(defect)
		egen countdefsecond = total(defect) if dummysecondval==1
		gen perccountdefsecond = countdefsecond/countdefectors
		mean(countdefectors) 
		mean(countdefsecond) 
		mean(perccountdefsecond)
	use temp, clear
	save temp, replace
		keep if treatment==2 & deswin==0
		egen countdefectors = total(defect)
		egen countdefsecond = total(defect) if dummysecondval==1
		gen perccountdefsecond = countdefsecond/countdefectors
		mean(countdefectors)
		mean(countdefsecond) 
		mean(perccountdefsecond)
	use temp, clear
	save temp, replace
		replace defectsecondval=defectthirdval if defectsecondval==.	// prepare for the ranksum
		keep if treatment==1 & (dummysecondval==1|dummythirdval==1)
		egen tagtemp = tag(matchinggroup dummythirdval)
		keep if tagtemp==1
		keep defectsecondval matchinggroup dummythirdval
		sum defectsecondval if dummythirdval==0
		sum defectsecondval if dummythirdval==1
		reshape wide defectsecondval, i(matchinggroup) j(dummythirdval)
		signrank defectsecondval0=defectsecondval1
	use temp, clear
	save temp, replace
		replace defectsecondval=defectthirdval if defectsecondval==.	// prepare for the ranksum
		keep if treatment==2 & (dummysecondval==1|dummythirdval==1)
		egen tagtemp = tag(matchinggroup dummythirdval)
		keep if tagtemp==1
		keep defectsecondval matchinggroup dummythirdval
		sum defectsecondval if dummythirdval==0
		sum defectsecondval if dummythirdval==1
		reshape wide defectsecondval, i(matchinggroup) j(dummythirdval)
		signrank defectsecondval0=defectsecondval1
	use temp, clear
		*footnote values and instability
	save temp, replace
		keep if tagstab==1 & treatment==1
		keep avgfirstvalstab matchinggroup unstable
		sum avgfirstvalstab if unstable==0
		sum avgfirstvalstab if unstable==1
		reshape wide avgfirstvalstab, i(matchinggroup) j(unstable)
		signrank avgfirstvalstab0=avgfirstvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==1
		keep avgsecondvalstab matchinggroup unstable
		sum avgsecondvalstab if unstable==0
		sum avgsecondvalstab if unstable==1
		reshape wide avgsecondvalstab, i(matchinggroup) j(unstable)
		signrank avgsecondvalstab0=avgsecondvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==1
		keep avgthirdvalstab matchinggroup unstable
		sum avgthirdvalstab if unstable==0
		sum avgthirdvalstab if unstable==1
		reshape wide avgthirdvalstab, i(matchinggroup) j(unstable)
		signrank avgthirdvalstab0=avgthirdvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==2
		keep avgfirstvalstab matchinggroup unstable
		sum avgfirstvalstab if unstable==0
		sum avgfirstvalstab if unstable==1
		reshape wide avgfirstvalstab, i(matchinggroup) j(unstable)
		signrank avgfirstvalstab0=avgfirstvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==2
		keep avgsecondvalstab matchinggroup unstable
		sum avgsecondvalstab if unstable==0
		sum avgsecondvalstab if unstable==1
		reshape wide avgsecondvalstab, i(matchinggroup) j(unstable)
		signrank avgsecondvalstab0=avgsecondvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==2
		keep avgthirdvalstab matchinggroup unstable
		sum avgthirdvalstab if unstable==0
		sum avgthirdvalstab if unstable==1
		reshape wide avgthirdvalstab, i(matchinggroup) j(unstable)
		signrank avgthirdvalstab0=avgthirdvalstab1
	use temp, clear

	*data for figure 1a																
	bysort treatment round: egen dr = total(defect)	
	gen defectround = 0										
	replace defectround = dr/(24*2)	if treatment<3		// 24 groups of 3, max 2 defectors
	replace defectround = dr/(9*2) if treatment>2		// 9 groups of 3, max 2 defectors
	*mean(defectround), over(treatment round)

	*data for figure 1b
	bysort treatment round: egen ur = total(unstable)
	gen unstableround = 0
	replace unstableround = ur/(24*3) if treatment<3
	replace unstableround = ur/(9*3) if treatment>2
	*mean(unstableround), over(treatment round)
	
	*figures 2a and 2b
	*heatplot unstable firstval secondval if treatment==1&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(@min @max) subtitle(unstable)) ylabel(, nogrid) xtitle(median value in cartel) ytitle(highest value in cartel)
	*heatplot unstable firstval secondval if treatment==2&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(@min @max) subtitle(unstable)) ylabel(, nogrid) xtitle(median value in cartel) ytitle(highest value in cartel)
	*heatplot unstable firstdiff seconddiff if treatment==1&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(@min @max) subtitle(unstable)) ylabel(, nogrid) xtitle(seconddiff) ytitle(firstdiff)
	*heatplot unstable firstdiff seconddiff if treatment==2&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(.2 @max) subtitle(unstable)) ylabel(, nogrid) xtitle(seconddiff) ytitle(firstdiff)
	
	
*4.2 revenue and efficiency


	*paragraph 1 & table 2
	save temp, replace
		keep if tagwinner==1 & treatment<3
		ranksum(avgrev), by(treatment)
		sum avgrev if treatment==1
		sum avgrev if treatment==2
	use temp, clear
	save temp, replace
		keep if tagwinnerstable==1 & treatment<3
		ranksum(avgrevun), by(treatment)
		sum avgrevun if treatment==1
		sum avgrevun if treatment==2
	use temp, clear
	save temp, replace
		keep if tagwinnerunstable==1 & treatment<3
		ranksum(avgrevun), by(treatment)
		sum avgrevun if treatment==1
		sum avgrevun if treatment==2
	use temp, clear
	save temp, replace
		keep if tagwinnerstab==1 & treatment==1
		keep avgrevun matchinggroup unstable
		mean(avgrevun), over(unstable)
		reshape wide avgrevun, i(matchinggroup) j(unstable)
		signrank avgrevun0=avgrevun1
	use temp, clear
	save temp, replace
		keep if tagwinnerstab==1 & treatment==2
		keep avgrevun matchinggroup unstable
		mean(avgrevun), over(unstable)
		reshape wide avgrevun, i(matchinggroup) j(unstable)
		signrank avgrevun0=avgrevun1
	use temp, clear
	save temp, replace
		keep if tagcross==1 & treatment<3
		ranksum(avgrevun), by(treatment)
	use temp, clear
	
	*paragraph 2
	save temp, replace
		keep if tagwinner==1 & treatment<3
		ranksum(avgrevvar), by(treatment)
		mean(avgrevvar), over(treatment)
	use temp, clear
	
	*paragraph 3 & table 1
	save temp, replace	
		keep if tagwinner==1 & treatment<3
		ranksum(probdeswinwins), by(treatment)
		sum probdeswinwins if treatment==1
		sum probdeswinwins if treatment==2
	use temp, clear
	save temp, replace
		keep if tagwinner==1 & treatment<3
		ranksum(efficiency), by(treatment)
		sum efficiency if treatment==1
		sum efficiency if treatment==2
	use temp, clear
	
	*data for figure 2
	*mean(bidfrac), over(treatment round unstable)
	
*4.3 bidding behavior
	
	*figures 5a and 5b
	*heatplot bid firstval secondval if treatment==1&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(19 63) subtitle(mean bid)) ylabel(, nogrid) 
	*heatplot bid firstval secondval if treatment==2&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(9 53) subtitle(mean bid)) ylabel(, nogrid)
	*heatplot bid secondval thirdval if treatment==1&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(20 64) subtitle(mean bid)) ylabel(, nogrid) xtitle(lowest value in cartel) ytitle(median value in cartel)
	*heatplot bid secondval thirdval if treatment==1&deswin==1, statistic(max) levels(80) hexagon ramp(right labels(@min @max) subtitle(highest bid)) ylabel(, nogrid) xtitle(lowest value in cartel) ytitle(median value in cartel)
	*heatplot bid secondval thirdval if treatment==2&deswin==1, statistic(mean) levels(80) hexagon ramp(right labels(9 54) subtitle(mean bid)) ylabel(, nogrid) xtitle(lowest value in cartel) ytitle(median value in cartel)
	*heatplot bid secondval thirdval if treatment==2&deswin==1, statistic(max) levels(80) hexagon ramp(right labels(@min @max) subtitle(highest bid)) ylabel(, nogrid) xtitle(lowest value in cartel) ytitle(median value in cartel)
	
	*paragraph 1
	save temp, replace
		keep if treatment<3 & bid>value
		keep if winner==1
	use temp, replace
	
	*paragraph 2
		*for point 1) see section 4.2, paragraph 3 
	save temp, replace
		keep if tagdeswin==1 & treatment==1
		signrank avgbiddeswin=ones
		mean(avgbiddeswin)
	use temp, clear
		save temp, replace
		keep if tagdefector==1 & treatment==1
		signrank avgbiddefector=ones
		mean(avgbiddefector)
	use temp, clear
	save temp, replace
		keep if treatment<3 & bid>value & deswin!=1
		keep if winner==1
	use temp, replace

	*paragraph 3
		*see appendix B below
		
	*paragraph 4
	save temp, replace
		keep if deswin==1&winner==0&bid<value&treatment==2
	use temp, clear
	save temp, replace
		keep if deswin==0&winner==1&bid<value&treatment==2
	use temp, clear
	save temp, replace
		keep if treatment==2 & deswin==0
		egen countdefectors = total(defect)
		egen countdefectorsbidzero = total(defect) if bid==0
		egen countdefectorsbidvalue = total(defect) if bid <= value & bid >= value-5
		egen countdefectorsbid15 = total(defect) if bid<=5 & bid>=1
		gen percdefectorsbidzero = countdefectorsbidzero/countdefectors
		gen percdefectorsbidvalue = countdefectorsbidvalue/countdefectors
		gen percdefectorsbid15 = countdefectorsbid15/countdefectors
		mean(percdefectorsbidzero)
		mean(percdefectorsbid15)
		mean(percdefectorsbidvalue)
	use temp, clear
	save temp, replace
		keep if defect==1&bid>value&treatment==2
	use temp, clear
	save temp, replace
		keep if tagdeslosewins==1 & treatment==2
		signrank avgbiddeslosewin=ones
		mean(avgbiddeslosewin)
	use temp, clear
	save temp, replace
		keep if tagdeswin==1 & treatment==2
		signrank probdeswinwins=ones
		mean(probdeswinwins)
	use temp, clear 

	*data for figures 4 and 5
		*figure 4 can be constructed directly from the raw data
	*mean(bidfrac), over(treatment round deswin)
	*mean(probdeswinwinsround), over(treatment round)

* Section 5: Study 2
*******************************************************************************	
	
	
*5.1 cartel stability
	
	
	*paragraph 1 & table 3
		*rank sum tests for comparisons between treatment 1 and 2 can be found in section 4.1, paragraph 1
	save temp, replace
		keep if tag==1 & (treatment==1|treatment==3)
		ranksum(defectgroup), by(treatment)
		ranksum(unstablegroup), by(treatment)
		sum defectgroup unstablegroup if treatment==1
		sum defectgroup unstablegroup if treatment==3
	use temp,clear
	save temp, replace
		keep if tag==1 & (treatment==2|treatment==4)
		ranksum(defectgroup), by(treatment)
		ranksum(unstablegroup), by(treatment)
		sum defectgroup unstablegroup if treatment==2
		sum defectgroup unstablegroup if treatment==4
	use temp,clear
	save temp, replace
		keep if tag==1 & treatment>2
		ranksum(defectgroup), by(treatment)
		ranksum(unstablegroup), by(treatment)
	use temp, clear
	save temp, replace
		replace defectsecondval=defectthirdval if defectsecondval==.	// prepare for the ranksum
		keep if treatment==3 & (dummysecondval==1|dummythirdval==1)
		egen tagtemp = tag(matchinggroup dummythirdval)
		keep if tagtemp==1
		keep defectsecondval matchinggroup dummythirdval
		mean(defectsecondval), over(dummythirdval)
		reshape wide defectsecondval, i(matchinggroup) j(dummythirdval)
		signrank defectsecondval0=defectsecondval1
	use temp, clear
	save temp, replace
		replace defectsecondval=defectthirdval if defectsecondval==.	// prepare for the ranksum
		keep if treatment==4 & (dummysecondval==1|dummythirdval==1)
		egen tagtemp = tag(matchinggroup dummythirdval)
		keep if tagtemp==1
		keep defectsecondval matchinggroup dummythirdval
		mean(defectsecondval), over(dummythirdval)
		reshape wide defectsecondval, i(matchinggroup) j(dummythirdval)
		signrank defectsecondval0=defectsecondval1
	use temp, clear
	
	*paragraph 2
	save temp, replace
		keep if tagstab==1 & treatment==4
		keep avgvalstab matchinggroup unstable
		mean(avgvalstab), over(unstable)
		reshape wide avgvalstab, i(matchinggroup) j(unstable)
		signrank avgvalstab0=avgvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==4
		keep sdvalstab matchinggroup unstable
		mean(sdvalstab), over(unstable)
		reshape wide sdvalstab, i(matchinggroup) j(unstable)
		signrank sdvalstab0=sdvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==3
		keep avgvalstab matchinggroup unstable
		mean(avgvalstab), over(unstable)
		reshape wide avgvalstab, i(matchinggroup) j(unstable)
		signrank avgvalstab0=avgvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==3
		keep sdvalstab matchinggroup unstable
		mean(sdvalstab), over(unstable)
		reshape wide sdvalstab, i(matchinggroup) j(unstable)
		signrank sdvalstab0=sdvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==3
		keep firstdiffstab matchinggroup unstable
		mean(firstdiffstab), over(unstable)
		reshape wide firstdiffstab, i(matchinggroup) j(unstable)
		signrank firstdiffstab0=firstdiffstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==4
		keep firstdiffstab matchinggroup unstable
		mean(firstdiffstab), over(unstable)
		reshape wide firstdiffstab, i(matchinggroup) j(unstable)
		signrank firstdiffstab0=firstdiffstab1
	use temp, clear	
	save temp, replace
		keep if tagstab==1 & treatment==3
		keep avgfirstvalstab matchinggroup unstable
		sum avgfirstvalstab if unstable==0
		sum avgfirstvalstab if unstable==1
		reshape wide avgfirstvalstab, i(matchinggroup) j(unstable)
		signrank avgfirstvalstab0=avgfirstvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==3
		keep avgsecondvalstab matchinggroup unstable
		sum avgsecondvalstab if unstable==0
		sum avgsecondvalstab if unstable==1
		reshape wide avgsecondvalstab, i(matchinggroup) j(unstable)
		signrank avgsecondvalstab0=avgsecondvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==3
		keep avgthirdvalstab matchinggroup unstable
		sum avgthirdvalstab if unstable==0
		sum avgthirdvalstab if unstable==1
		reshape wide avgthirdvalstab, i(matchinggroup) j(unstable)
		signrank avgthirdvalstab0=avgthirdvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==4
		keep avgfirstvalstab matchinggroup unstable
		sum avgfirstvalstab if unstable==0
		sum avgfirstvalstab if unstable==1
		reshape wide avgfirstvalstab, i(matchinggroup) j(unstable)
		signrank avgfirstvalstab0=avgfirstvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==4
		keep avgsecondvalstab matchinggroup unstable
		sum avgsecondvalstab if unstable==0
		sum avgsecondvalstab if unstable==1
		reshape wide avgsecondvalstab, i(matchinggroup) j(unstable)
		signrank avgsecondvalstab0=avgsecondvalstab1
	use temp, clear
	save temp, replace
		keep if tagstab==1 & treatment==4
		keep avgthirdvalstab matchinggroup unstable
		sum avgthirdvalstab if unstable==0
		sum avgthirdvalstab if unstable==1
		reshape wide avgthirdvalstab, i(matchinggroup) j(unstable)
		signrank avgthirdvalstab0=avgthirdvalstab1
	use temp, clear
	
	
*5.2 revenue and efficiency
	
	
	*paragraph 1 & tables 4 and 5
		*rank sum tests for comparisons between treatment 1 and 2 can be found in section 4.2
	save temp, replace
		keep if tagwinner==1 & treatment>2
		ranksum(avgrev), by(treatment)
		ranksum(avgrevvar), by(treatment)
		sum avgrev avgrevvar if treatment==3
		sum avgrev avgrevvar if treatment==4
	use temp, clear
	save temp, replace
		keep if tagwinnerstable==1 & treatment>2
		ranksum(avgrevun), by(treatment)
		sum avgrevun if treatment==3
		sum avgrevun if treatment==4
	use temp, clear
	save temp, replace
		keep if tagwinnerunstable==1 & treatment>2
		ranksum(avgrevun), by(treatment)
		sum avgrevun if treatment==3
		sum avgrevun if treatment==4
	use temp, clear
	save temp, replace
		keep if tagwinnerstab==1 & treatment==3
		keep avgrevun matchinggroup unstable
		reshape wide avgrevun, i(matchinggroup) j(unstable)
		signrank avgrevun0=avgrevun1
	use temp, clear
	save temp, replace
		keep if tagwinnerstab==1 & treatment==4
		keep avgrevun matchinggroup unstable
		reshape wide avgrevun, i(matchinggroup) j(unstable)
		signrank avgrevun0=avgrevun1
	use temp, clear
	save temp, replace
		keep if tagcross==1 & treatment>2
		ranksum(avgrevun), by(treatment)
	use temp, clear	
	save temp, replace
		keep if tagwinner==1 & (treatment==1|treatment==3)
		ranksum(avgrev), by(treatment)
		ranksum(avgrevvar), by(treatment)
		sum avgrevvar if treatment==1
	use temp, clear
	save temp, replace
		keep if tagwinner==1 & (treatment==2|treatment==4)
		ranksum(avgrev), by(treatment)
		ranksum(avgrevvar), by(treatment)
		sum avgrevvar if treatment==2
	use temp, clear
	
	*paragraph 2 & table 6
	save temp, replace	
		keep if tagwinner==1 & treatment>2
		ranksum(probdeswinwins), by(treatment)
		sum probdeswinwins if treatment==3
		sum probdeswinwins if treatment==4
	use temp, clear
	save temp, replace	
		keep if tagwinner==1 & (treatment==1|treatment==3)
		ranksum(probdeswinwins), by(treatment)
		sum probdeswinwins if treatment==1
	use temp, clear
	save temp, replace	
		keep if tagwinner==1 & (treatment==2|treatment==4)
		ranksum(probdeswinwins), by(treatment)
		sum probdeswinwins if treatment==2
	use temp, clear
	save temp, replace
		keep if tagwinner==1 & treatment>2
		ranksum(efficiency), by(treatment)
		sum efficiency if treatment==3
		sum efficiency if treatment==4
	use temp, clear
	save temp, replace
		keep if tagwinner==1 & (treatment==1|treatment==3)
		ranksum(efficiency), by(treatment)
		sum efficiency if treatment==1
	use temp, clear
	save temp, replace
		keep if tagwinner==1 & (treatment==2|treatment==4)
		ranksum(efficiency), by(treatment)
		sum efficiency if treatment==2
	use temp, clear
	
*5.3 bidding behavior
	
	
	*paragraph 1
		*for point 1) see section 5.2, paragraph 2 
	save temp, replace
		keep if tagdeswin==1 & treatment==3
		signrank avgbiddeswin=ones
		mean(avgbiddeswin)
	use temp, clear
	save temp, replace
		keep if tagdefector==1 & treatment==3
		signrank avgbiddefector=ones
		mean(avgbiddefector)
	use temp, clear
	save temp, replace
		keep if deswin==0&bid>value&treatment==3
		keep if winner==1
	use temp, clear
	save temp, replace
		keep if tagdeslosewins==1 & treatment==3
		signrank avgbiddeslosewin=ones
		mean(avgbiddeslosewin)
	use temp, clear
	
	*paragraph 2
	save temp, replace
		keep if tagdeswin==1 & treatment==4
		signrank probdeswinwins=ones
	use temp, clear 
	save temp, replace
		keep if tagdefector==1 & treatment==4
		signrank avgbiddefector=ones
	use temp, clear
	save temp, replace
		keep if treatment==4 & defect==1
		egen countsecondbidabove = total(defect) if bid>value
		mean(countsecondbidabove)
		egen countsecondbidabovewin = total(defect) if bid>value & winner==1
		mean(countsecondbidabovewin)
		egen countsecondwinsurplus = total(defect) if winner==1 & bid<value
		mean(countsecondwinsurplus)
		egen countsecondwinbelowfirst = total(defect) if winner==1 & bid<firstval
		mean(countsecondwinbelowfirst)
	use temp, clear
	save temp, replace
		keep if treatment==4 & deswin==0
		egen countdefectors = total(defect)
		egen countdefectorsbidzero = total(defect) if bid==0
		egen countdefectorsbidvalue = total(defect) if bid <= value & bid >= value-5
		egen countdefectorsbid15 = total(defect) if bid<=5 & bid>=1
		gen percdefectorsbidzero = countdefectorsbidzero/countdefectors
		gen percdefectorsbidvalue = countdefectorsbidvalue/countdefectors
		gen percdefectorsbid15 = countdefectorsbid15/countdefectors
		mean(percdefectorsbid15)
		mean(percdefectorsbidvalue)
	use temp, clear
	
	*data for figure 6
	*mean(bidfrac), over(treatment round deswin)
	*mean(probdeswinwinsround), over(treatment round)
	
	
* Appendix B: Out of equilibrium bidding behavior for the FPSB
*******************************************************************************



* Appendix C: Convergence of bidding behavior for the FPSB
*******************************************************************************

